@@ -223,7 +223,7 @@ _handles = _model_and_phase_handles + _energy_handles
 
 _data = ('_MW', '_Tm', '_Tb', '_Tt', '_Tc', '_Pt', '_Pc', '_Vc',
          '_Hf', '_S0', '_LHV', '_HHV', '_Hfus', '_Sfus', '_omega', '_dipole',
-         '_similarity_variable', '_iscyclic_aliphatic', '_combustion')
+         '_similarity_variable', '_iscyclic_aliphatic', '_combustion',)
 
 _functor_data = {'MW', 'Tm', 'Tb', 'Tt', 'Pt', 'Tc', 'Pc', 'Vc',
                  'Hfus', 'Sfus', 'omega', 'dipole',
@@ -341,7 +341,7 @@ class Chemical:
              Vc: 5.6e-05 m^3/mol
              Hf: -2.8582e+05 J/mol
              S0: 70 J/K/mol
-             LHV: 44011 J/mol
+             LHV: -44011 J/mol
              HHV: 0 J/mol
              Hfus: 6010 J/mol
              Sfus: None
@@ -549,7 +549,7 @@ class Chemical:
 
     @classmethod
     def blank(cls, ID, CAS=None, phase_ref=None, phase=None,
-              formula=None, **data):
+              formula=None, synonyms=None, **data):
         """
         Return a new Chemical object without any thermodynamic models or data 
         (unless provided).
@@ -612,8 +612,8 @@ class Chemical:
         self._Dortmund = DortmundGroupCounts()
         self._PSRK = PSRKGroupCounts()
         self._NIST = NISTGroupCounts()
+        self.synonyms = synonyms or ()
         setfield = setattr
-        self._synonyms = set()
         for i in _names: setfield(self, i, None)
         for i in _data: setfield(self, i, None)
         for i in _energy_handles: setfield(self, i, None)
@@ -675,8 +675,8 @@ class Chemical:
                  Vc: 0.000414 m^3/mol
                  Hf: -1.2711e+06 J/mol
                  S0: 0 J/K/mol
-                 LHV: -2.5406e+06 J/mol
-                 HHV: -2.8047e+06 J/mol
+                 LHV: 2.5406e+06 J/mol
+                 HHV: 2.8047e+06 J/mol
                  Hfus: 0 J/mol
                  Sfus: None
                  omega: 2.387
@@ -861,7 +861,7 @@ class Chemical:
         return self._synonyms
     @synonyms.setter
     def synonyms(self, synonyms):
-        self._synonyms = set(synonyms)
+        self._synonyms = set([synonyms]) if isinstance(synonyms, str) else set(synonyms)
     
     @property
     def InChI(self):
@@ -1137,7 +1137,6 @@ class Chemical:
     def Sfus(self, Sfus):
         reset_energy_constant(self, 'Sfus', float(Sfus))
     
-    
     @property
     def omega(self):
         """Accentric factor [-]."""
@@ -1170,7 +1169,6 @@ class Chemical:
     def iscyclic_aliphatic(self, iscyclic_aliphatic):
         reset_constant(self, 'iscyclic_aliphatic', bool(iscyclic_aliphatic))
     
-    
     ### Reaction data ###
     
     @property
@@ -1391,8 +1389,8 @@ class Chemical:
         based on the molecular formula and the heat of formation."""
         cd = combustion_data(self.atoms, Hf=self._Hf, MW=self._MW, method=method)
         if not self._MW: self._MW = cd.MW
-        self._LHV = cd.LHV
-        self._HHV = cd.HHV
+        self._LHV = - cd.LHV
+        self._HHV = - cd.HHV
         self._combustion = cd.stoichiometry
     
     def reset_free_energies(self):
@@ -1415,7 +1413,7 @@ class Chemical:
         self._pubchemid = pubchemid
         self._iupac_name = iupac_name
         self._common_name = common_name
-        self._synonyms = set(synonyms or ())
+        self.synonyms = synonyms or ()
         self._formula = formula
         
     def _init_groups(self, InChI_key):
@@ -1479,8 +1477,8 @@ class Chemical:
         atoms = atoms or self.atoms
         if not all([LHV, HHV, combustion]) and atoms and Hf:
             cd = combustion_data(atoms, Hf=self._Hf, MW=self._MW, missing_handling='Ash')
-            LHV = cd.LHV
-            HHV = cd.HHV
+            LHV = - cd.LHV
+            HHV = - cd.HHV
             combustion = cd.stoichiometry
         self._LHV = LHV
         self._HHV = HHV
@@ -1851,9 +1849,9 @@ class Chemical:
                     if 'Hf' in properties:
                         self._Hf = cd.Hf
                     if 'HHV' in properties:
-                        self._HHV = cd.HHV
+                        self._HHV = - cd.HHV
                     if 'LHV' in properties:
-                        self._LHV = cd.LHV
+                        self._LHV = - cd.LHV
                     if 'combustion' in properties:
                         self._combustion = stoichiometry
         else:
