@@ -487,10 +487,10 @@ class CompiledChemicals(Chemicals):
         """
         dct = self.__dict__
         chemicals = self.tuple
-        dct['MW'] = chemical_data_array([i.MW for i in chemicals])
-        dct['Hf'] = chemical_data_array([i.Hf for i in chemicals])
-        dct['LHV'] = chemical_data_array([i.LHV for i in chemicals])
-        dct['HHV'] = chemical_data_array([i.HHV for i in chemicals])
+        dct['MW'] = chemical_data_array(chemicals, 'MW')
+        dct['Hf'] = chemical_data_array(chemicals, 'Hf')
+        dct['LHV'] = chemical_data_array(chemicals, 'LHV')
+        dct['HHV'] = chemical_data_array(chemicals, 'HHV')
 
     def get_combustion_reactions(self):
         """
@@ -695,8 +695,8 @@ class CompiledChemicals(Chemicals):
         ValueError: synonym 'H2O' already in use by Chemical('Water')
         
         """
-        chemical = getattr(self, ID)
         dct = self.__dict__
+        chemical = dct[ID]
         if synonym in dct and dct[synonym] is not chemical:
             raise ValueError(f"synonym '{synonym}' already in use by {repr(dct[synonym])}")
         else:
