@@ -28,7 +28,6 @@ def get_phase_fraction(stream, phases):
             phase_fraction += imol[phase].sum() 
     return phase_fraction / F_mol
 
-
 class MultiStream(Stream):
     """
     Create a MultiStream object that defines material flow rates for multiple
@@ -187,8 +186,9 @@ class MultiStream(Stream):
     """
     __slots__ = ()
     def __init__(self, ID="", flow=(), T=298.15, P=101325., phases=('g', 'l'), 
-                 units=None, price=0, total_flow=None,
-                 thermo=None, **phase_flows):
+                 units=None, price=0, total_flow=None, thermo=None, 
+                 characterization_factors=None, **phase_flows):
+        self.characterization_factors = {} if characterization_factors is None else {}
         self._thermal_condition = ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         chemicals = thermo.chemicals
@@ -291,6 +291,7 @@ class MultiStream(Stream):
             stream._bubble_point_cache =  self._bubble_point_cache
             stream._dew_point_cache = self._dew_point_cache
             stream._property_cache = {}
+            stream.characterization_factors = {}
             stream._property_cache_key = None, None
             streams[phase] = stream
         return stream
