@@ -8,6 +8,7 @@
 """
 """
 import thermosteam as tmo
+from .units_of_measure import AbsoluteUnitsOfMeasure
 
 __all__ = ('settings',)
 
@@ -16,12 +17,15 @@ def raise_no_thermo_error():
                        "use settings.set_thermo")
 
 class Settings:
-    __slots__ = ('_thermo',
-                 '_phase_names',
-                 '_debug',
+    __slots__ = (
+        'impact_indicators',
+        '_thermo',
+        '_phase_names',
+        '_debug',
     )
     
     def __init__(self):
+        self.impact_indicators = {}
         self._thermo = None
         self._debug = False
         self._phase_names = {'s': 'Solid',
@@ -30,6 +34,19 @@ class Settings:
                              'S': 'SOLID',
                              'L': 'LIQUID',
                              'G': 'GAS'}
+    
+    def define_impact_indicator(self, key, units):
+        self.impact_indicators[key] = AbsoluteUnitsOfMeasure(units)
+    
+    def get_impact_indicator_units(self, key):
+        try:
+            return tmo.settings.impact_indicators[key]
+        except KeyError:
+            raise ValueError(
+                f"impact indicator key '{key}' has no defined units; "
+                 "units can be defined through `thermosteam.settings.define_impact_indicator`"
+            )
+    
     @property
     def debug(self):
         """[bool] If True, additional checks may raise errors at runtime."""
@@ -45,8 +62,8 @@ class Settings:
     
     def get_default_thermo(self, thermo):
         """
-        Return a default Thermo object.
-        If `thermo` is a Thermo object, return the same object.
+        Return default Thermo object if `thermo` is None. Otherwise, return 
+        the same object.
         
         """
         return thermo if thermo else self.get_thermo()
