@@ -10,6 +10,7 @@
 import numpy as np
 import thermosteam as tmo
 import flexsolve as flx
+from warnings import warn
 from thermosteam import functional as fn
 from . import indexer
 from . import equilibrium as eq
@@ -39,6 +40,7 @@ class StreamData:
     
 # %%
 
+@utils.units_of_measure(thermo_units.stream_units_of_measure)
 @utils.thermo_user
 @utils.registered(ticket_name='s')
 class Stream:
@@ -72,6 +74,8 @@ class Stream:
     thermo : :class:`~thermosteam.Thermo`, optional
         Thermo object to initialize input and output streams. Defaults to
         `biosteam.settings.get_thermo()`.
+    characterization_factors : dict, optional
+        Characterization factors for life cycle assessment.
     **chemical_flows : float
         ID - flow pairs.
     
@@ -237,8 +241,8 @@ class Stream:
     __slots__ = ('_ID', '_imol', '_thermal_condition', '_thermo', '_streams',
                  '_bubble_point_cache', '_dew_point_cache',
                  '_vle_cache', '_lle_cache', '_sle_cache',
-                 '_sink', '_source', '_price', '_link',
-                 '_property_cache_key', '_property_cache')
+                 '_sink', '_source', '_price', '_link', '_property_cache_key',
+                 '_property_cache', 'characterization_factors')
     line = 'Stream'
     
     #: [DisplayUnits] Units of measure for IPython display (class attribute)
@@ -247,11 +251,15 @@ class Stream:
                                               composition=False,
                                               N=7)
 
+    _units_of_measure = thermo_units.stream_units_of_measure
+
     _flow_cache = {}
 
     def __init__(self, ID= '', flow=(), phase='l', T=298.15, P=101325.,
                  units=None, price=0., total_flow=None, thermo=None, 
-                 **chemical_flows):
+                 characterization_factors=None, **chemical_flows):
+        #: dict[obj, float] Characterization factors for life cycle assessment in impact / kg.
+        self.characterization_factors = {} if characterization_factors is None else {}
         self._thermal_condition = tmo.ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         chemicals = thermo.chemicals
@@ -299,6 +307,78 @@ class Stream:
                 stream._imol = self._imol.get_phase(phase)
                 stream._thermo = thermo
 
+    def get_CF(self, key, units=None):
+        """
+        Returns the life-cycle characterization factor on a kg basis given the
+        impact indicator key.
+        
+        Parameters
+        ----------
+        key : str
+            Key of impact indicator.
+        units : str, optional
+            Units of impact indicator. Before using this argument, the default units 
+            of the impact indicator should be defined with 
+            thermosteam.settings.define_impact_indicator.
+            Units must also be dimensionally consistent with the default units.
+        
+        """
+        try:
+            value = self.characterization_factors[key]
+        except:
+            return 0.
+        if units is not None:
+            original_units = tmo.settings.get_impact_indicator_units(key)
+            value = original_units.convert(value, units)
+        return value
+    
+    def set_CF(self, key, value, units=None):
+        """
+        Set the life-cycle characterization factor on a kg basis given the 
+        impact indicator key and the units of measure.
+        
+        Parameters
+        ----------
+        key : str
+            Key of impact indicator.
+        value : float
+            Characterization factor value.
+        units : str, optional
+            Units of impact indicator. Before using this argument, the default units 
+            of the impact indicator should be defined with 
+            thermosteam.settings.define_impact_indicator.
+            Units must also be dimensionally consistent with the default units.
+        
+        """
+        if units is not None:
+            original_units = tmo.settings.get_impact_indicator_units(key)
+            value = original_units.unconvert(value, units)
+        self.characterization_factors[key] = value
+
+    def get_impact(self, key):
+        """Return hourly rate of the impact indicator given the key."""
+        cfs = self.characterization_factors
+        return cfs[key] * self.F_mass if key in cfs else 0.
+
+    def empty_negative_flows(self):
+        """
+        Replace flows of all components with negative values with 0.
+
+        Examples
+        --------
+        >>> import thermosteam as tmo
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
+        >>> s1 = tmo.Stream('s1', Water=1, Ethanol=-1)
+        >>> s1.empty_negative_flows()
+        >>> s1.show()
+        Stream: s1
+         phase: 'l', T: 298.15 K, P: 101325 Pa
+         flow (kmol/hr): Water  1
+
+        """
+        data = self._imol._data
+        data[data < 0.] = 0.
+
     def shares_flow_rate_with(self, other):
         """
         Return whether other stream shares data with this one.
@@ -440,10 +520,7 @@ class Stream:
         
         """
         material = self._imol._data
-        if fn.infeasible(material):
-            raise InfeasibleRegion('negative material flow rate')
-        else:
-            material[material < 0.] = 0. 
+        if material[material < 0.].any(): raise InfeasibleRegion('negative material flow rate')
 
     @property
     def vapor_fraction(self):
@@ -669,65 +746,6 @@ class Stream:
         name, factor = self._get_flow_name_and_factor(units)
         setattr(self, 'F_' + name, value / factor)
     
-    def get_property(self, name, units):
-        """
-        Return property in requested units.
-
-        Parameters
-        ----------
-        name : str
-            Name of stream property.
-        units : str
-            Units of measure.
-
-        Examples
-        --------
-        >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
-        >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
-        >>> s1.get_property('sigma', 'N/m') # Surface tension
-        0.06384
-
-        """
-        value = getattr(self, name)
-        units_dct = thermo_units.stream_units_of_measure
-        if name in units_dct:
-            original_units = units_dct[name]
-        else:
-            raise ValueError(f"'{name}' is not thermodynamic property")
-        return original_units.convert(value, units)
-    
-    def set_property(self, name, value, units):
-        """
-        Set property in given units.
-
-        Parameters
-        ----------
-        name : str
-            Name of stream property.
-        value : str
-            New value of stream property.
-        units : str
-            Units of measure.
-
-        Examples
-        --------
-        >>> import thermosteam as tmo
-        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
-        >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
-        >>> s1.set_property('P', 2, 'atm')
-        >>> s1.P
-        202650.0
-
-        """
-        units_dct = thermo_units.stream_units_of_measure
-        if name in units_dct:
-            original_units = units_dct[name]
-        else:
-            raise ValueError(f"no property with name '{name}'")
-        value = original_units.unconvert(value, units)
-        setattr(self, name, value)
-    
     ### Stream data ###
 
     @property
@@ -831,7 +849,7 @@ class Stream:
     @property
     def F_mass(self):
         """[float] Total mass flow rate in kg/hr."""
-        return (self.chemicals.MW * self.mol).sum()
+        return np.dot(self.chemicals.MW, self.mol)
     @F_mass.setter
     def F_mass(self, value):
         F_mass = self.F_mass
@@ -1206,6 +1224,7 @@ class Stream:
         elif N_others == 1:
             self.copy_like(others[0])
         else:
+            self.P = others[0].P
             if energy_balance: H = sum([i.H for i in others])
             self._imol.mix_from([i._imol for i in others])
             if energy_balance and not self.isempty():
@@ -1347,10 +1366,10 @@ class Stream:
         RuntimeError: phase is locked; stream cannot be unlinked
         
         """
+        imol = self._imol
+        if hasattr(imol, '_phase') and isinstance(imol._phase, tmo._phase.LockedPhase):
+            raise RuntimeError('phase is locked; stream cannot be unlinked')
         if self._link:
-            imol = self._imol
-            if hasattr(imol, '_phase') and isinstance(imol._phase, tmo._phase.LockedPhase):
-                raise RuntimeError('phase is locked; stream cannot be unlinked')
             imol._data_cache.clear()
             imol._data = imol._data.copy()
             imol._phase = imol._phase.copy()
@@ -1571,12 +1590,13 @@ class Stream:
         
         Warnings
         --------
-        Prices are not copied.
+        Prices, LCA characterization factors are not copied are not copied.
         
         """
         cls = self.__class__
         new = cls.__new__(cls)
         new._link = new._sink = new._source = None
+        new.characterization_factors = {}
         new._thermo = thermo or self._thermo
         new._imol = self._imol.copy()
         if thermo and thermo.chemicals is not self.chemicals:
@@ -1611,6 +1631,7 @@ class Stream:
         imol._data = self._imol._data
         new._thermal_condition = self._thermal_condition.copy()
         new.reset_cache()
+        new.characterization_factors = {}
         new._link = self
         return new
     
