@@ -22,6 +22,7 @@ from .._phase import NoPhase, phase_tuple
 from ..indexer import ChemicalIndexer, MaterialIndexer
 from ..exceptions import InfeasibleRegion
 import numpy as np
+import pandas as pd
 
 __all__ = ('Reaction', 'ReactionItem', 'ReactionSet', 
            'ParallelReaction', 'SeriesReaction', 'ReactionSystem',
@@ -36,12 +37,6 @@ def get_stoichiometric_string(stoichiometry, phases, chemicals):
         return prs.get_stoichiometric_string(stoichiometry, 
                                              chemicals)
 
-def check_material_feasibility(material: np.ndarray):
-    if fn.infeasible(material):
-        raise InfeasibleRegion('not enough reactants; reaction conversion')
-    else:
-        material[material < 0.] = 0. 
-
 def set_reaction_basis(rxn, basis):
     if basis != rxn._basis:
         if basis == 'wt':
@@ -205,7 +200,7 @@ class Reaction:
     >>> combustion = mixed_reaction - fermentation
     >>> combustion.show()
     Reaction (by mol):
-     stoichiometry                reactant    X[%]
+     stoichiometry              reactant    X[%]
      Glucose + O2 -> H2O + CO2  Glucose    20.00
     
     When a Reaction object is multiplied (or divided), a new Reaction object
@@ -214,7 +209,7 @@ class Reaction:
     >>> combustion_multiplied = 2 * combustion
     >>> combustion_multiplied.show()
     Reaction (by mol):
-     stoichiometry                reactant    X[%]
+     stoichiometry              reactant    X[%]
      Glucose + O2 -> H2O + CO2  Glucose    40.00
     >>> fermentation_divided = fermentation / 2
     >>> fermentation_divided.show()
@@ -275,21 +270,30 @@ class Reaction:
         return [i for i,j in zip(self._chemicals, self._stoichiometry) if j]
     
     def reset_chemicals(self, chemicals):
-        reaction = get_stoichiometric_string(self.stoichiometry, self.phases, self.chemicals)
-        return self.__init__(reaction, reactant=self.reactant, X=self.X, basis=self.basis, chemicals=chemicals)
-    
-    def __eq__(self, other):
-        try:
-            return all([
-                self._basis == other._basis,
-                self._phases == other._phases,
-                self._chemicals is other._chemicals,
-                self._X_index == other._X_index,
-                (self._stoichiometry == other._stoichiometry).all(),
-                self._X == other._X,
-            ])
-        except:
-            return False
+        if self._chemicals is chemicals: return
+        phases = self.phases
+        stoichiometry = self._stoichiometry
+        reactant = self.reactant
+        if phases:
+            M, N = stoichiometry.shape
+            new_stoichiometry = np.zeros([M, chemicals.size])
+            IDs = self._chemicals.IDs
+            for i in range(M):
+                for j in range(N):
+                    value = stoichiometry[i, j]
+                    if value: new_stoichiometry[i, chemicals.index(IDs[j])] = value
+            phase, reactant = reactant
+            X_index = phases.index(phase), chemicals.index(reactant)
+        else:
+            new_stoichiometry = np.zeros(chemicals.size)
+            IDs = self._chemicals.IDs
+            for i in range(len(IDs)):
+                value = stoichiometry[i]
+                if value: new_stoichiometry[chemicals.index(IDs[i])] = value
+            X_index = chemicals.index(reactant)
+        self._chemicals = chemicals
+        self._stoichiometry = new_stoichiometry
+        self._X_index = X_index
     
     def copy(self, basis=None):
         """Return copy of Reaction object."""
@@ -383,7 +387,12 @@ class Reaction:
         values = material_array.value if isproperty else material_array
         self._reaction(values)
         if tmo.reaction.CHECK_FEASIBILITY:
-            check_material_feasibility(values)
+            negatives = values < 0.
+            if negatives.any():
+                if values[negatives].sum() < -1e-16:
+                    raise InfeasibleRegion('not enough reactants; reaction conversion')
+                else:
+                    values[negatives] = 0.
         else:
             fn.remove_negligible_negative_values(values)
         if isproperty: material_array[:] = values
@@ -806,6 +815,15 @@ class Reaction:
             raise RuntimeError(f"reactant '{self.reactant}' does not participate in stoichiometric reaction")
         self._stoichiometry /= new_scale
     
+    def to_df(self, index=None):
+        columns = [f'Stoichiometry (by {self.basis})', 'Reactant', 'Conversion [%]']
+        stoichiometry = get_stoichiometric_string(self.stoichiometry, self.phases, self.chemicals)
+        reactant = self.reactant
+        conversion = 100. * self.X
+        df = pd.DataFrame(data=[[stoichiometry, reactant, conversion]], columns=columns, index=[index] if index else None)
+        df.index.name = 'Reaction'
+        return df
+    
     def __repr__(self):
         reaction = get_stoichiometric_string(self.stoichiometry, self.phases, self.chemicals)
         return f"{type(self).__name__}('{reaction}', reactant='{self.reactant}', X={self.X:.3g}, basis={repr(self.basis)})"
@@ -845,7 +863,7 @@ class ReactionItem(Reaction):
         Index of reaction.
         
     """
-    __slots__ = ('_index')
+    __slots__ = ('_index', '_parent')
     phases = MaterialIndexer.phases
     
     def __init__(self, rxnset, index):
@@ -856,9 +874,16 @@ class ReactionItem(Reaction):
         self._chemicals = rxnset._chemicals
         self._X_index = rxnset._X_index[index]
         self._index = index
+        self._parent = rxnset
     
     def reset_chemicals(self, chemicals):
-        raise TypeError('cannot reset chemicals of a reaction item')
+        if self._chemicals is chemicals: return
+        parent = self._parent
+        parent.reset_chemicals(chemicals)
+        index = self._index
+        self._stoichiometry = parent._stoichiometry[index]
+        self._X_index = parent._X_index[index]
+        self._chemicals = chemicals
     
     @property
     def basis(self):
@@ -898,8 +923,7 @@ class ReactionSet:
     reactions : Iterable[Reaction]
     
     """
-    __slots__ = Reaction.__slots__
-    __eq__ = Reaction.__eq__
+    __slots__ = (*Reaction.__slots__, '_parent_index')
     copy = Reaction.copy
     phases = MaterialIndexer.phases
     _get_stoichiometry_by_mol = Reaction._get_stoichiometry_by_mol
@@ -937,15 +961,43 @@ class ReactionSet:
             rxnset._X = self._X[index]
             rxnset._X_index = self._X_index[index]
             rxnset._chemicals = self._chemicals
+            rxnset._parent_index = (self, index)
             return rxnset
     
     def reset_chemicals(self, chemicals):
-        reactions = [self[i] for i in range(self._stoichiometry.shape[0])]
-        self.__init__(
-            [Reaction(get_stoichiometric_string(i.stoichiometry, i.phases, i.chemicals), 
-                      i.reactant, i.X, chemicals, i.basis, phases=i.phases)
-             for i in reactions]
-        )
+        if chemicals is self._chemicals: return
+        if hasattr(self, '_parent_index'):
+            parent, index = self._parent_index
+            parent.reset_chemicals(chemicals)
+            self._stoichiometry = parent._stoichiometry[index]
+            self._X_index = parent._X_index[index]
+            self._chemicals = parent._chemicals
+            return
+        phases = self.phases
+        stoichiometry = self._stoichiometry
+        reactants = self.reactants
+        if phases:
+            A, B, C = stoichiometry.shape
+            new_stoichiometry = np.zeros([A, B, chemicals.size])
+            IDs = self._chemicals.IDs
+            for i in range(A):
+                for j in range(B):
+                    for k in range(C):
+                        value = stoichiometry[i, j, k]
+                        if value: new_stoichiometry[i, j, chemicals.index(IDs[k])] = value
+            X_index = tuple([(phases.index(i), chemicals.index(j)) for i, j in reactants])
+        else:
+            A, B = stoichiometry.shape
+            new_stoichiometry = np.zeros([A, chemicals.size])
+            IDs = self._chemicals.IDs
+            for i in range(A):
+                for j in range(B):
+                    value = stoichiometry[i, j]
+                    if value: new_stoichiometry[i, chemicals.index(IDs[j])] = value
+            X_index = tuple([chemicals.index(i) for i in reactants])
+        self._chemicals = chemicals
+        self._stoichiometry = new_stoichiometry
+        self._X_index = X_index
     
     @property
     def reaction_chemicals(self):
@@ -994,6 +1046,21 @@ class ReactionSet:
         """[2d array] Molecular weights of all chemicals."""
         return self._chemicals.MW[np.newaxis, :]
     
+    def to_df(self, index=None):
+        columns = [f'Stoichiometry (by {self.basis})', 'Reactant', 'Conversion [%]']
+        chemicals = self._chemicals
+        phases = self._phases
+        rxns = [get_stoichiometric_string(i, phases, chemicals) for i in self._stoichiometry]
+        cmps = [ID + ',' + phase for phase, ID in self.reactants] if phases else self.reactants
+        Xs = 100. * self.X
+        data = list([i for i in zip(rxns, cmps, Xs) if i[2]])
+        df = pd.DataFrame(data, columns=columns, index=index if index else None)
+        if isinstance(self, ParallelReaction):
+            df.index.name = 'Parallel reaction'
+        elif isinstance(self, SeriesReaction):
+            df.index.name = 'Reaction in series'
+        return df
+    
     def __repr__(self):
         return f"{type(self).__name__}([{', '.join([repr(i).replace('ReactionItem', 'Reaction') for i in self])}])"
     
