@@ -103,16 +103,12 @@ def format_units(units, ends='$', mathrm=True):
 def reformat_units(name):
     left, right = name.split('[')
     units, right = right.split(']')
-    return f"{left} [{format_units(units)}] {right}"
+    return f"{left} [{format_units(units)}]{right}"
 
 format_plot_units = format_units
 
-def get_dimensionality(units, cache={}):
-    if units in cache:
-        dim = cache[units]
-    else:
-        cache[units] = dim = ureg._get_dimensionality(to_units_container(units, ureg))
-    return dim
+def get_dimensionality(units):
+    return ureg._get_dimensionality(to_units_container(units, ureg))
 
 # %% Manage conversion factors
 
@@ -262,71 +258,86 @@ class DisplayUnits:
 
 # %% Units of measure
 
-chemical_units_of_measure = {'MW': AbsoluteUnitsOfMeasure('g/mol'),
-                             'T': RelativeUnitsOfMeasure('K'),
-                             'Tr': RelativeUnitsOfMeasure('K'),
-                             'Tm': RelativeUnitsOfMeasure('K'),
-                             'Tb': RelativeUnitsOfMeasure('K'),
-                             'Tbr': RelativeUnitsOfMeasure('K'),
-                             'Tt': RelativeUnitsOfMeasure('K'),
-                             'Tc': RelativeUnitsOfMeasure('K'),
-                             'P': AbsoluteUnitsOfMeasure('Pa'),
-                             'Pr': AbsoluteUnitsOfMeasure('Pa'),
-                             'Pc': AbsoluteUnitsOfMeasure('Pa'),
-                             'Psat': AbsoluteUnitsOfMeasure('Pa'),
-                             'Pt': AbsoluteUnitsOfMeasure('Pa'),
-                             'V': AbsoluteUnitsOfMeasure('m^3/mol'),
-                             'Vc': AbsoluteUnitsOfMeasure('m^3/mol'),
-                             'Cp': AbsoluteUnitsOfMeasure('J/g/K'),
-                             'Cn': AbsoluteUnitsOfMeasure('J/mol/K'),
-                             'R': AbsoluteUnitsOfMeasure('J/mol/K'),
-                             'rho': AbsoluteUnitsOfMeasure('kg/m^3'),
-                             'rhoc': AbsoluteUnitsOfMeasure('kg/m^3'),
-                             'nu': AbsoluteUnitsOfMeasure('m^2/s'),
-                             'alpha': AbsoluteUnitsOfMeasure('m^2/s'),
-                             'mu': AbsoluteUnitsOfMeasure('Pa*s'),
-                             'sigma': AbsoluteUnitsOfMeasure('N/m'),
-                             'kappa': AbsoluteUnitsOfMeasure('W/m/K'),
-                             'Hvap': AbsoluteUnitsOfMeasure('J/mol'),
-                             'H': AbsoluteUnitsOfMeasure('J/mol'),  
-                             'Hf': AbsoluteUnitsOfMeasure('J/mol'), 
-                             'Hc': AbsoluteUnitsOfMeasure('J/mol'), 
-                             'Hfus': AbsoluteUnitsOfMeasure('J/mol'), 
-                             'Hsub': AbsoluteUnitsOfMeasure('J/mol'),
-                             'HHV': AbsoluteUnitsOfMeasure('J/mol'),
-                             'LHV': AbsoluteUnitsOfMeasure('J/mol'),
-                             'S': AbsoluteUnitsOfMeasure('J/K/mol'),
-                             'S0': AbsoluteUnitsOfMeasure('J/K/mol'),
-                             'G': AbsoluteUnitsOfMeasure('J/mol'), 
-                             'U': AbsoluteUnitsOfMeasure('J/mol'),
-                             'H_excess': AbsoluteUnitsOfMeasure('J/mol'), 
-                             'S_excess': AbsoluteUnitsOfMeasure('J/mol'),
-                             'dipole': AbsoluteUnitsOfMeasure('Debye'),
-                             'delta': AbsoluteUnitsOfMeasure('Pa^0.5'),
-                             'epsilon': AbsoluteUnitsOfMeasure(''),
+chemical_units_of_measure = {
+    'MW': AbsoluteUnitsOfMeasure('g/mol'),
+    'T': RelativeUnitsOfMeasure('K'),
+    'Tr': RelativeUnitsOfMeasure('K'),
+    'Tm': RelativeUnitsOfMeasure('K'),
+    'Tb': RelativeUnitsOfMeasure('K'),
+    'Tbr': RelativeUnitsOfMeasure('K'),
+    'Tt': RelativeUnitsOfMeasure('K'),
+    'Tc': RelativeUnitsOfMeasure('K'),
+    'P': AbsoluteUnitsOfMeasure('Pa'),
+    'Pr': AbsoluteUnitsOfMeasure('Pa'),
+    'Pc': AbsoluteUnitsOfMeasure('Pa'),
+    'Psat': AbsoluteUnitsOfMeasure('Pa'),
+    'Pt': AbsoluteUnitsOfMeasure('Pa'),
+    'V': AbsoluteUnitsOfMeasure('m^3/mol'),
+    'Vc': AbsoluteUnitsOfMeasure('m^3/mol'),
+    'Cp': AbsoluteUnitsOfMeasure('J/g/K'),
+    'Cn': AbsoluteUnitsOfMeasure('J/mol/K'),
+    'R': AbsoluteUnitsOfMeasure('J/mol/K'),
+    'rho': AbsoluteUnitsOfMeasure('kg/m^3'),
+    'rhoc': AbsoluteUnitsOfMeasure('kg/m^3'),
+    'nu': AbsoluteUnitsOfMeasure('m^2/s'),
+    'alpha': AbsoluteUnitsOfMeasure('m^2/s'),
+    'mu': AbsoluteUnitsOfMeasure('Pa*s'),
+    'sigma': AbsoluteUnitsOfMeasure('N/m'),
+    'kappa': AbsoluteUnitsOfMeasure('W/m/K'),
+    'Hvap': AbsoluteUnitsOfMeasure('J/mol'),
+    'H': AbsoluteUnitsOfMeasure('J/mol'),  
+    'Hf': AbsoluteUnitsOfMeasure('J/mol'), 
+    'Hc': AbsoluteUnitsOfMeasure('J/mol'), 
+    'Hfus': AbsoluteUnitsOfMeasure('J/mol'), 
+    'Hsub': AbsoluteUnitsOfMeasure('J/mol'),
+    'HHV': AbsoluteUnitsOfMeasure('J/mol'),
+    'LHV': AbsoluteUnitsOfMeasure('J/mol'),
+    'S': AbsoluteUnitsOfMeasure('J/K/mol'),
+    'S0': AbsoluteUnitsOfMeasure('J/K/mol'),
+    'G': AbsoluteUnitsOfMeasure('J/mol'), 
+    'U': AbsoluteUnitsOfMeasure('J/mol'),
+    'H_excess': AbsoluteUnitsOfMeasure('J/mol'), 
+    'S_excess': AbsoluteUnitsOfMeasure('J/mol'),
+    'dipole': AbsoluteUnitsOfMeasure('Debye'),
+    'delta': AbsoluteUnitsOfMeasure('Pa^0.5'),
+    'epsilon': AbsoluteUnitsOfMeasure(''),
 }
-stream_units_of_measure = {'mol': AbsoluteUnitsOfMeasure('kmol/hr'),
-                           'mass': AbsoluteUnitsOfMeasure('kg/hr'),
-                           'vol': AbsoluteUnitsOfMeasure('m^3/hr'),
-                           'F_mass': AbsoluteUnitsOfMeasure('kg/hr'),
-                           'F_mol': AbsoluteUnitsOfMeasure('kmol/hr'),
-                           'F_vol': AbsoluteUnitsOfMeasure('m^3/hr'),
-                           'cost': AbsoluteUnitsOfMeasure('USD/hr'),
-                           'Hvap': AbsoluteUnitsOfMeasure('kJ/hr'),
-                           'Hf': AbsoluteUnitsOfMeasure('kJ/hr'), 
-                           'S0': AbsoluteUnitsOfMeasure('kJ/K/hr'), 
-                           'Hc': AbsoluteUnitsOfMeasure('kJ/hr'), 
-                           'H': AbsoluteUnitsOfMeasure('kJ/hr'),
-                           'S': AbsoluteUnitsOfMeasure('kJ/K/hr'),
-                           'G': AbsoluteUnitsOfMeasure('kJ/hr'),
-                           'U': AbsoluteUnitsOfMeasure('kJ/hr'),
-                           'C': AbsoluteUnitsOfMeasure('kJ/hr/K'),
+stream_units_of_measure = {
+    'mol': AbsoluteUnitsOfMeasure('kmol/hr'),
+    'mass': AbsoluteUnitsOfMeasure('kg/hr'),
+    'vol': AbsoluteUnitsOfMeasure('m^3/hr'),
+    'F_mass': AbsoluteUnitsOfMeasure('kg/hr'),
+    'F_mol': AbsoluteUnitsOfMeasure('kmol/hr'),
+    'F_vol': AbsoluteUnitsOfMeasure('m^3/hr'),
+    'cost': AbsoluteUnitsOfMeasure('USD/hr'),
+    'HHV': AbsoluteUnitsOfMeasure('kJ/hr'),
+    'LHV': AbsoluteUnitsOfMeasure('kJ/hr'),
+    'Hvap': AbsoluteUnitsOfMeasure('kJ/hr'),
+    'Hf': AbsoluteUnitsOfMeasure('kJ/hr'), 
+    'S0': AbsoluteUnitsOfMeasure('kJ/K/hr'), 
+    'Hc': AbsoluteUnitsOfMeasure('kJ/hr'), 
+    'H': AbsoluteUnitsOfMeasure('kJ/hr'),
+    'S': AbsoluteUnitsOfMeasure('kJ/K/hr'),
+    'G': AbsoluteUnitsOfMeasure('kJ/hr'),
+    'U': AbsoluteUnitsOfMeasure('kJ/hr'),
+    'C': AbsoluteUnitsOfMeasure('kJ/hr/K'),
 }
 for i in ('T', 'P', 'mu', 'V', 'rho', 'sigma',
           'kappa', 'nu', 'epsilon', 'delta',
           'Psat', 'Cp', 'Cn', 'alpha'):
     stream_units_of_measure[i] = chemical_units_of_measure[i]
 
+power_utility_units_of_measure = {
+    'rate': AbsoluteUnitsOfMeasure('kW'),
+    'consumption': AbsoluteUnitsOfMeasure('kW'),
+    'production': AbsoluteUnitsOfMeasure('kW'),
+}
+
+heat_utility_units_of_measure = {
+    'flow': AbsoluteUnitsOfMeasure('kmol/hr'),
+    'duty': AbsoluteUnitsOfMeasure('kJ/hr'),
+}
+
 definitions = {'MW': 'Molecular weight',
                'T': 'Temperature',
                'Tr': 'Reduced temperature',
